package com.zhyc.module.biosafety.service;

import java.util.List;

import com.zhyc.module.biosafety.domain.Diagnosis;

/**
 * 诊疗结果Service接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
public interface IDiagnosisService 
{
    /**
     * 查询诊疗结果
     * 
     * @param id 诊疗结果主键
     * @return 诊疗结果
     */
    public Diagnosis selectDiagnosisById(Long id);

    /**
     * 查询诊疗结果列表
     * 
     * @param diagnosis 诊疗结果
     * @return 诊疗结果集合
     */
    public List<Diagnosis> selectDiagnosisList(Diagnosis diagnosis);

    /**
     * 新增诊疗结果
     * 
     * @param diagnosis 诊疗结果
     * @return 结果
     */
    public int insertDiagnosis(Diagnosis diagnosis);

    /**
     * 修改诊疗结果
     * 
     * @param diagnosis 诊疗结果
     * @return 结果
     */
    public int updateDiagnosis(Diagnosis diagnosis);

    /**
     * 批量删除诊疗结果
     * 
     * @param ids 需要删除的诊疗结果主键集合
     * @return 结果
     */
    public int deleteDiagnosisByIds(Long[] ids);

    /**
     * 删除诊疗结果信息
     * 
     * @param id 诊疗结果主键
     * @return 结果
     */
    public int deleteDiagnosisById(Long id);

    int insertDiagnosisList(Diagnosis diagnosis);
}
